const appInsights = require("applicationinsights"); //telemetry
var express = require('express'),
    bodyParser = require('body-parser'), //parsing middleware
    localizify = require('localizify'); //for translation and localization for messages

var app = express();

var port = process.env.PORT || 3000;

var router = express.Router();

app.use(bodyParser.urlencoded({ extended: true }));
app.use(bodyParser.json());

//messages are default to English
const en = require('./resources/en.json');
localizify.add('en', en).setLocale('en');
const { t } = require('localizify');


//determine if in test environment or not
var db;
if (process.env.ENV == 'Test')
    db = "./tests/data/testproviders.json";
else {
    db = "./data/json/providers.json";
}
console.log("ENVIRONMENT: " + process.env.ENV == 'Test');

var providerController = require('./controllers/providerController')(db);

//set up telemetry
appInsights.setup("4406b621-e8a9-44d1-8996-41906befaafd");
appInsights.start();

router.route('/Providers')
    .get(providerController.getProviderList)
    .post(providerController.postProvider)
    .delete(providerController.deleteProvider)
    .put(providerController.putProvider)

router.route('/Providers/:name')
    .get(providerController.getProviderByName)

app.use('/api', router);


app.get('/', function (req, res) {
    res.send(t("readme"));
});

app.listen(port, function () {
    console.log("Running on PORT: " + port);
});

module.exports = app;

