'use strict';
var fs = require('fs'), //for reading and writing to a file
    localizify = require('localizify'); //for translation and localization for messages

//error messages are default to English
const en = require('../resources/en.json');
localizify.add('en', en).setLocale('en');
const { t } = require('localizify');

module.exports = {
    read: function (path) {

        /// <summary>Reads a JSON file from given path</summary>  
        /// <param name="path" type="String">Path to the file that will be read</param>  
        /// <returns type="String">The file read as a String</returns> 

        try {
            var contents = fs.readFileSync(path, 'utf8');
            return contents;
        }
        catch (err) {
            if (err.code == 'ENOENT') {
                throw new Error(t('file_not_found'));
            }
            else if (err.code == 'EISDIR') {
                throw new Error(t('illegal_operation_on_directory'));
            }
            else {
                throw err;
            }
        }
    },

    write: function (path, data) {

        /// <summary>Writes data to a JSON file on the given path</summary>  
        /// <param name="path" type="String">Path to the file that will be written to</param>  
        /// <param name="data" type="String">data that will be written</param> 


        try {
            fs.writeFileSync(path, data);
        }
        catch (err) {
            if (err.code == 'EISDIR') {
                throw new Error(t('illegal_operation_on_directory'));
            }
            throw err;
        }
    }
}