var should = require('should'),
    dataManagement = require('../data/dataManagement.js'),
    fs = require('fs');

var providerControllerFile = '../controllers/providerController.js';
var testJSON = './data/testproviders.json';

describe('Data Tests:', function () {
    it('should write empty string to file', function () {

        dataManagement.write(testJSON, "");

        var str = fs.readFileSync(testJSON, 'utf8');

        str.should.be.an.instanceof(String);
        str.should.equal("");
    })
    it('should write to file', function () {

        dataManagement.write(testJSON, "Testing Writing to File");

        var str = fs.readFileSync(testJSON, 'utf8');

        str.should.be.an.instanceof(String);
        str.should.equal("Testing Writing to File");
    })
    it('should overwrite to file', function () {

        fs.writeFileSync(testJSON, "TESTING");

        dataManagement.write(testJSON, "Overwriting");

        var str = fs.readFileSync(testJSON, 'utf8');

        str.should.be.an.instanceof(String);
        str.should.equal("Overwriting");
    })
    it('should read empty string in file', function () {

        var str = dataManagement.read(testJSON);

        str.should.be.an.instanceof(String);
        str.should.equal("");
    })
    it('should read string in file', function () {

        fs.writeFileSync(testJSON, "Reading from file test");

        var str = dataManagement.read(testJSON);

        str.should.be.an.instanceof(String);
        str.should.equal("Reading from file test");
    })
    it("should get an error while reading: 'Illegal Operation on a Directory'", function () {

        var directory = './data';
        should(function () { dataManagement.read(directory) }).throw('Illegal Operation on a Directory');
    })
    it("should get an error while reading: 'File Not Found'", function () {

        var nonexistentFile = './data/nonexistentFile.json';
        should(function () { dataManagement.read(nonexistentFile); }).throw('File Not Found');
    })
    it("should get an error while writing: 'Illegal Operation on a Directory'", function () {

        var directory = './data';
        should(function () { dataManagement.write(directory, "NOT ALLOWED") }).throw('Illegal Operation on a Directory');
    })

    afterEach(function () {
        fs.writeFileSync(testJSON, "");
    });

})